@@ -1,9 +1,11 @@
 <?php
 /**
  * @author Björn Schießle <schiessle@owncloud.com>
+ * @author Joas Schilling <nickvergessen@owncloud.com>
  * @author Lukas Reschke <lukas@owncloud.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <icewind@owncloud.com>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
  * @copyright Copyright (c) 2015, ownCloud, Inc.
@@ -61,76 +63,81 @@ $externalManager = new \OCA\Files_Sharing\External\Manager(
 		\OC\Files\Filesystem::getMountManager(),
 		\OC\Files\Filesystem::getLoader(),
 		\OC::$server->getHTTPHelper(),
+		\OC::$server->getNotificationManager(),
 		\OC::$server->getUserSession()->getUser()->getUID()
 );
 
 // check for ssl cert
-
-if (substr($remote, 0, 5) === 'https' and !OC_Util::getUrlContent($remote)) {
-	\OCP\JSON::error(array('data' => array('message' => $l->t('Invalid or untrusted SSL certificate'))));
-	exit;
-} else {
-	$mount = $externalManager->addShare($remote, $token, $password, $name, $ownerDisplayName, true);
-
-	/**
-	 * @var \OCA\Files_Sharing\External\Storage $storage
-	 */
-	$storage = $mount->getStorage();
+if (substr($remote, 0, 5) === 'https') {
 	try {
-		// check if storage exists
-		$storage->checkStorageAvailability();
+		\OC::$server->getHTTPClientService()->newClient()->get($remote)->getBody();
+	} catch (\Exception $e) {
+		\OCP\JSON::error(array('data' => array('message' => $l->t('Invalid or untrusted SSL certificate'))));
+		exit;
+	}
+}
+
+$mount = $externalManager->addShare($remote, $token, $password, $name, $ownerDisplayName, true);
+
+/**
+ * @var \OCA\Files_Sharing\External\Storage $storage
+ */
+$storage = $mount->getStorage();
+try {
+	// check if storage exists
+	$storage->checkStorageAvailability();
+} catch (\OCP\Files\StorageInvalidException $e) {
+	// note: checkStorageAvailability will already remove the invalid share
+	\OCP\Util::writeLog(
+		'files_sharing',
+		'Invalid remote storage: ' . get_class($e) . ': ' . $e->getMessage(),
+		\OCP\Util::DEBUG
+	);
+	\OCP\JSON::error(
+		array(
+			'data' => array(
+				'message' => $l->t('Could not authenticate to remote share, password might be wrong')
+			)
+		)
+	);
+	exit();
+} catch (\Exception $e) {
+	\OCP\Util::writeLog(
+		'files_sharing',
+		'Invalid remote storage: ' . get_class($e) . ': ' . $e->getMessage(),
+		\OCP\Util::DEBUG
+	);
+	$externalManager->removeShare($mount->getMountPoint());
+	\OCP\JSON::error(array('data' => array('message' => $l->t('Storage not valid'))));
+	exit();
+}
+$result = $storage->file_exists('');
+if ($result) {
+	try {
+		$storage->getScanner()->scanAll();
+		\OCP\JSON::success();
 	} catch (\OCP\Files\StorageInvalidException $e) {
-		// note: checkStorageAvailability will already remove the invalid share
 		\OCP\Util::writeLog(
 			'files_sharing',
 			'Invalid remote storage: ' . get_class($e) . ': ' . $e->getMessage(),
 			\OCP\Util::DEBUG
 		);
-		\OCP\JSON::error(
-			array(
-				'data' => array(
-					'message' => $l->t('Could not authenticate to remote share, password might be wrong')
-				)
-			)
-		);
-		exit();
+		\OCP\JSON::error(array('data' => array('message' => $l->t('Storage not valid'))));
 	} catch (\Exception $e) {
 		\OCP\Util::writeLog(
 			'files_sharing',
 			'Invalid remote storage: ' . get_class($e) . ': ' . $e->getMessage(),
 			\OCP\Util::DEBUG
 		);
-		$externalManager->removeShare($mount->getMountPoint());
-		\OCP\JSON::error(array('data' => array('message' => $l->t('Storage not valid'))));
-		exit();
-	}
-	$result = $storage->file_exists('');
-	if ($result) {
-		try {
-			$storage->getScanner()->scanAll();
-			\OCP\JSON::success();
-		} catch (\OCP\Files\StorageInvalidException $e) {
-			\OCP\Util::writeLog(
-				'files_sharing',
-				'Invalid remote storage: ' . get_class($e) . ': ' . $e->getMessage(),
-				\OCP\Util::DEBUG
-			);
-			\OCP\JSON::error(array('data' => array('message' => $l->t('Storage not valid'))));
-		} catch (\Exception $e) {
-			\OCP\Util::writeLog(
-				'files_sharing',
-				'Invalid remote storage: ' . get_class($e) . ': ' . $e->getMessage(),
-				\OCP\Util::DEBUG
-			);
-			\OCP\JSON::error(array('data' => array('message' => $l->t('Couldn\'t add remote share'))));
-		}
-	} else {
-		$externalManager->removeShare($mount->getMountPoint());
-		\OCP\Util::writeLog(
-			'files_sharing',
-			'Couldn\'t add remote share',
-			\OCP\Util::DEBUG
-		);
 		\OCP\JSON::error(array('data' => array('message' => $l->t('Couldn\'t add remote share'))));
 	}
+} else {
+	$externalManager->removeShare($mount->getMountPoint());
+	\OCP\Util::writeLog(
+		'files_sharing',
+		'Couldn\'t add remote share',
+		\OCP\Util::DEBUG
+	);
+	\OCP\JSON::error(array('data' => array('message' => $l->t('Couldn\'t add remote share'))));
 }
+
