@@ -4,8 +4,8 @@ OC.L10N.register(
     "Could not revert: %s" : "No se pudo revertir: %s ",
     "Versions" : "Versiones",
     "Failed to revert {file} to revision {timestamp}." : "Falló al revertir {file} a la revisión {timestamp}.",
-    "More versions..." : "Más versiones...",
+    "Restore" : "Recuperar",
     "No other versions available" : "No hay más versiones disponibles",
-    "Restore" : "Recuperar"
+    "More versions..." : "Más versiones..."
 },
 "nplurals=2; plural=(n != 1);");
