@@ -27,6 +27,7 @@
 namespace OC\Core;
 
 use OC\AppFramework\Utility\SimpleContainer;
+use OC\AppFramework\Utility\TimeFactory;
 use \OCP\AppFramework\App;
 use OC\Core\LostPassword\Controller\LostController;
 use OC\Core\User\UserController;
@@ -63,7 +64,9 @@ class Application extends App {
 				$c->query('SecureRandom'),
 				$c->query('DefaultEmailAddress'),
 				$c->query('IsEncryptionEnabled'),
-				$c->query('Mailer')
+				$c->query('Mailer'),
+				$c->query('TimeFactory'),
+				$c->query('Logger')
 			);
 		});
 		$container->registerService('UserController', function(SimpleContainer $c) {
@@ -83,6 +86,7 @@ class Application extends App {
 				$c->query('L10N'),
 				$c->query('UserManager'),
 				$c->query('UserSession'),
+				$c->query('UserFolder'),
 				$c->query('Logger')
 			);
 		});
@@ -117,8 +121,9 @@ class Application extends App {
 		$container->registerService('Cache', function(SimpleContainer $c) {
 			return $c->query('ServerContainer')->getCache();
 		});
-
-
+		$container->registerService('UserFolder', function(SimpleContainer $c) {
+			return $c->query('ServerContainer')->getUserFolder();
+		});
 		$container->registerService('Defaults', function() {
 			return new \OC_Defaults;
 		});
@@ -128,6 +133,9 @@ class Application extends App {
 		$container->registerService('Logger', function(SimpleContainer $c) {
 			return $c->query('ServerContainer')->getLogger();
 		});
+		$container->registerService('TimeFactory', function(SimpleContainer $c) {
+			return new TimeFactory();
+		});
 		$container->registerService('DefaultEmailAddress', function() {
 			return Util::getDefaultEmailAddress('lostpassword-noreply');
 		});
