@@ -1,6 +1,7 @@
 OC.L10N.register(
     "lib",
     {
-    "Personal" : "Անձնական"
+    "Personal" : "Անձնական",
+    "today" : "այսօր"
 },
 "nplurals=2; plural=(n != 1);");
