@@ -189,8 +189,9 @@ class Updater {
 		list($targetStorage, $targetInternalPath) = $this->view->resolvePath($target);
 
 		if ($sourceStorage && $targetStorage) {
-			$targetCache = $targetStorage->getCache($sourceInternalPath);
-			if ($sourceStorage->getCache($sourceInternalPath)->inCache($sourceInternalPath)) {
+			$sourceCache = $sourceStorage->getCache($sourceInternalPath);
+			$targetCache = $targetStorage->getCache($targetInternalPath);
+			if ($sourceCache->inCache($sourceInternalPath)) {
 				if ($targetCache->inCache($targetInternalPath)) {
 					$targetCache->remove($targetInternalPath);
 				}
@@ -208,7 +209,7 @@ class Updater {
 				$targetCache->update($fileId, array('mimetype' => $mimeType));
 			}
 
-			$targetCache->correctFolderSize($sourceInternalPath);
+			$sourceCache->correctFolderSize($sourceInternalPath);
 			$targetCache->correctFolderSize($targetInternalPath);
 			$this->correctParentStorageMtime($sourceStorage, $sourceInternalPath);
 			$this->correctParentStorageMtime($targetStorage, $targetInternalPath);
