@@ -1,28 +1,48 @@
 <?php
 /**
- * ownCloud
+ * @author Arthur Schiwon <blizzz@owncloud.com>
+ * @author Bart Visscher <bartv@thisnet.nl>
+ * @author Brice Maron <brice@bmaron.net>
+ * @author Christopher Schäpers <kondou@ts.unde.re>
+ * @author Felix Moeller <mail@felixmoeller.de>
+ * @author Frank Karlitschek <frank@owncloud.org>
+ * @author Georg Ehrke <georg@owncloud.com>
+ * @author Jakob Sack <mail@jakobsack.de>
+ * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Kamil Domanski <kdomanski@kdemail.net>
+ * @author Lukas Reschke <lukas@owncloud.com>
+ * @author michag86 <micha_g@arcor.de>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Robin Appelman <icewind@owncloud.com>
+ * @author Robin McCorkell <rmccorkell@karoshi.org.uk>
+ * @author root <root@oc.(none)>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Thomas Tanghus <thomas@tanghus.net>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @author Robin Appelman
- * @copyright 2012 Frank Karlitschek frank@owncloud.org
+ * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @license AGPL-3.0
  *
- * @author Georg Ehrke
- * @copytight 2014 Georg Ehrke georg@ownCloud.com
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3,
+ * as published by the Free Software Foundation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Affero General Public License, version 3,
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
 
+use OC\App\CodeChecker\CodeChecker;
+use OC\App\CodeChecker\EmptyCheck;
+use OC\App\CodeChecker\PrivateCheck;
+use OC\OCSClient;
+
 /**
  * This class provides the functionality needed to install, update and remove plugins/apps
  */
@@ -102,7 +122,7 @@ class OC_Installer{
 
 		//install the database
 		if(is_file($basedir.'/appinfo/database.xml')) {
-			if (OC_Appconfig::getValue($info['id'], 'installed_version') === null) {
+			if (\OC::$server->getAppConfig()->getValue($info['id'], 'installed_version') === null) {
 				OC_DB::createDbFromStructure($basedir.'/appinfo/database.xml');
 			} else {
 				OC_DB::updateDbFromStructure($basedir.'/appinfo/database.xml');
@@ -115,8 +135,8 @@ class OC_Installer{
 		}
 
 		//set the installed version
-		OC_Appconfig::setValue($info['id'], 'installed_version', OC_App::getAppVersion($info['id']));
-		OC_Appconfig::setValue($info['id'], 'enabled', 'no');
+		\OC::$server->getAppConfig()->setValue($info['id'], 'installed_version', OC_App::getAppVersion($info['id']));
+		\OC::$server->getAppConfig()->setValue($info['id'], 'enabled', 'no');
 
 		//set remote/public handelers
 		foreach($info['remote'] as $name=>$path) {
@@ -139,7 +159,7 @@ class OC_Installer{
 	 * Checks whether or not an app is installed, i.e. registered in apps table.
 	 */
 	public static function isInstalled( $app ) {
-		return (OC_Appconfig::getValue($app, "installed_version") !== null);
+		return (\OC::$server->getAppConfig()->getValue($app, "installed_version") !== null);
 	}
 
 	/**
@@ -172,7 +192,7 @@ class OC_Installer{
 	 *   -# setting the installed version
 	 *
 	 * upgrade.php can determine the current installed version of the app using
-	 * "OC_Appconfig::getValue($appid, 'installed_version')"
+	 * "\OC::$server->getAppConfig()->getValue($appid, 'installed_version')"
 	 */
 	public static function updateApp( $info=array(), $isShipped=false) {
 		list($extractDir, $path) = self::downloadApp($info);
@@ -204,20 +224,26 @@ class OC_Installer{
 
 	/**
 	 * update an app by it's id
-	 * @param integer $ocsid
+	 *
+	 * @param integer $ocsId
 	 * @return bool
 	 * @throws Exception
 	 */
-	public static function updateAppByOCSId($ocsid) {
-		$appdata = OC_OCSClient::getApplication($ocsid, \OC_Util::getVersion());
-		$download = OC_OCSClient::getApplicationDownload($ocsid, 1, \OC_Util::getVersion());
+	public static function updateAppByOCSId($ocsId) {
+		$ocsClient = new OCSClient(
+			\OC::$server->getHTTPClientService(),
+			\OC::$server->getConfig(),
+			\OC::$server->getLogger()
+		);
+		$appData = $ocsClient->getApplication($ocsId, \OC_Util::getVersion());
+		$download = $ocsClient->getApplicationDownload($ocsId, \OC_Util::getVersion());
 
 		if (isset($download['downloadlink']) && trim($download['downloadlink']) !== '') {
 			$download['downloadlink'] = str_replace(' ', '%20', $download['downloadlink']);
 			$info = array(
 				'source' => 'http',
 				'href' => $download['downloadlink'],
-				'appdata' => $appdata
+				'appdata' => $appData
 			);
 		} else {
 			throw new \Exception('Could not fetch app info!');
@@ -241,12 +267,14 @@ class OC_Installer{
 		//download the file if necessary
 		if($data['source']=='http') {
 			$pathInfo = pathinfo($data['href']);
-			$path=OC_Helper::tmpFile('.' . $pathInfo['extension']);
+			$extension = isset($pathInfo['extension']) ? '.' . $pathInfo['extension'] : '';
+			$path = \OC::$server->getTempManager()->getTemporaryFile($extension);
 			if(!isset($data['href'])) {
 				throw new \Exception($l->t("No href specified when installing app from http"));
 			}
-			file_put_contents($path, \OC_Util::getUrlContent($data['href']));
-		}else{
+			$client = \OC::$server->getHTTPClientService()->newClient();
+			$client->get($data['href'], ['save_to' => $path]);
+		} else {
 			if(!isset($data['path'])) {
 				throw new \Exception($l->t("No path specified when installing app from local file"));
 			}
@@ -287,7 +315,7 @@ class OC_Installer{
 	 * @return array
 	 * @throws \Exception
 	 */
-	public static function checkAppsIntegrity($data = array(), $extractDir, $path, $isShipped=false) {
+	public static function checkAppsIntegrity($data, $extractDir, $path, $isShipped=false) {
 		$l = \OC::$server->getL10N('lib');
 		//load the info.xml file of the app
 		if(!is_file($extractDir.'/appinfo/info.xml')) {
@@ -312,7 +340,7 @@ class OC_Installer{
 		}
 		$info=OC_App::getAppInfo($extractDir.'/appinfo/info.xml', true);
 		// check the code for not allowed calls
-		if(!$isShipped && !OC_Installer::checkCode($info['id'], $extractDir)) {
+		if(!$isShipped && !OC_Installer::checkCode($extractDir)) {
 			OC_Helper::rmdirr($extractDir);
 			throw new \Exception($l->t("App can't be installed because of not allowed code in the App"));
 		}
@@ -368,11 +396,15 @@ class OC_Installer{
 			return false;
 		}
 
-		$ocsid=OC_Appconfig::getValue( $app, 'ocsid', '');
+		$ocsid=\OC::$server->getAppConfig()->getValue( $app, 'ocsid', '');
 
 		if($ocsid<>'') {
-
-			$ocsdata=OC_OCSClient::getApplication($ocsid, \OC_Util::getVersion());
+			$ocsClient = new OCSClient(
+				\OC::$server->getHTTPClientService(),
+				\OC::$server->getConfig(),
+				\OC::$server->getLogger()
+			);
+			$ocsdata = $ocsClient->getApplication($ocsid, \OC_Util::getVersion());
 			$ocsversion= (string) $ocsdata['version'];
 			$currentversion=OC_App::getAppVersion($app);
 			if (version_compare($ocsversion, $currentversion, '>')) {
@@ -457,7 +489,7 @@ class OC_Installer{
 
 			return true;
 		}else{
-			OC_Log::write('core', 'can\'t remove app '.$name.'. It is not installed.', OC_Log::ERROR);
+			\OCP\Util::writeLog('core', 'can\'t remove app '.$name.'. It is not installed.', \OCP\Util::ERROR);
 
 			return false;
 		}
@@ -480,7 +512,7 @@ class OC_Installer{
 								$enabled = isset($info['default_enable']);
 								if( $enabled ) {
 									OC_Installer::installShippedApp($filename);
-									OC_Appconfig::setValue($filename, 'enabled', 'yes');
+									\OC::$server->getAppConfig()->setValue($filename, 'enabled', 'yes');
 								}
 							}
 						}
@@ -510,12 +542,12 @@ class OC_Installer{
 		if (is_null($info)) {
 			return false;
 		}
-		OC_Appconfig::setValue($app, 'installed_version', OC_App::getAppVersion($app));
+		\OC::$server->getAppConfig()->setValue($app, 'installed_version', OC_App::getAppVersion($app));
 		if (array_key_exists('ocsid', $info)) {
-			OC_Appconfig::setValue($app, 'ocsid', $info['ocsid']);
+			\OC::$server->getAppConfig()->setValue($app, 'ocsid', $info['ocsid']);
 		}
 
-		//set remote/public handelers
+		//set remote/public handlers
 		foreach($info['remote'] as $name=>$path) {
 			OCP\CONFIG::setAppValue('core', 'remote_'.$name, $app.'/'.$path);
 		}
@@ -533,59 +565,15 @@ class OC_Installer{
 	 * @param string $folder the folder of the app to check
 	 * @return boolean true for app is o.k. and false for app is not o.k.
 	 */
-	public static function checkCode($appname, $folder) {
-		$blacklist=array(
-			// classes replaced by the public api
-			'OC_API::',
-			'OC_App::',
-			'OC_AppConfig::',
-			'OC_Avatar',
-			'OC_BackgroundJob::',
-			'OC_Config::',
-			'OC_DB::',
-			'OC_Files::',
-			'OC_Helper::',
-			'OC_Hook::',
-			'OC_Image::',
-			'OC_JSON::',
-			'OC_L10N::',
-			'OC_Log::',
-			'OC_Mail::',
-			'OC_Preferences::',
-			'OC_Request::',
-			'OC_Response::',
-			'OC_Template::',
-			'OC_User::',
-			'OC_Util::',
-		);
-
+	public static function checkCode($folder) {
 		// is the code checker enabled?
-		if(OC_Config::getValue('appcodechecker', false)) {
-			// check if grep is installed
-			$grep = \OC_Helper::findBinaryPath('grep');
-			if (!$grep) {
-				OC_Log::write('core',
-					'grep not installed. So checking the code of the app "'.$appname.'" was not possible',
-					OC_Log::ERROR);
-				return true;
-			}
-
-			// iterate the bad patterns
-			foreach($blacklist as $bl) {
-				$cmd = 'grep --include \\*.php -ri '.escapeshellarg($bl).' '.$folder.'';
-				$result = exec($cmd);
-				// bad pattern found
-				if($result<>'') {
-					OC_Log::write('core',
-						'App "'.$appname.'" is using a not allowed call "'.$bl.'". Installation refused.',
-						OC_Log::ERROR);
-					return false;
-				}
-			}
-			return true;
-
-		}else{
+		if(!OC_Config::getValue('appcodechecker', false)) {
 			return true;
 		}
+
+		$codeChecker = new CodeChecker(new PrivateCheck(new EmptyCheck()));
+		$errors = $codeChecker->analyseFolder($folder);
+
+		return empty($errors);
 	}
 }
